package cn.com.infosec.ocsp;

import cn.com.infosec.asn1.ASN1OutputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.ocsp.BasicOCSPResponse;
import cn.com.infosec.asn1.ocsp.ResponseData;
import cn.com.infosec.asn1.ocsp.SingleResponse;
import cn.com.infosec.asn1.x509.X509Extensions;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.security.NoSuchProviderException;
import java.security.PublicKey;
import java.security.Signature;
import java.security.cert.CertStore;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.security.cert.X509Extension;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class BasicOCSPResp implements X509Extension {
   BasicOCSPResponse resp;
   ResponseData data;
   X509Certificate[] chain = null;

   public BasicOCSPResp(BasicOCSPResponse resp) {
      this.resp = resp;
      this.data = resp.getTbsResponseData();
   }

   private Set getExtensionOIDs(boolean critical) {
      BasicOCSPResp var10000 = this;
      HashSet var5;
      var5 = new HashSet.<init>();
      X509Extensions var2;
      if ((var2 = var10000.getResponseExtensions()) != null) {
         Enumeration var3 = var2.oids();

         while(var3.hasMoreElements()) {
            DERObjectIdentifier var4;
            if (critical == var2.getExtension(var4 = (DERObjectIdentifier)var3.nextElement()).isCritical()) {
               var5.add(var4.getId());
            }
         }
      }

      return var5;
   }

   private List getCertList(String provider) {
      BasicOCSPResp var10000 = this;
      ArrayList var8;
      var8 = new ArrayList.<init>();
      ByteArrayOutputStream var2;
      var2 = new ByteArrayOutputStream.<init>();
      ASN1OutputStream var3;
      var3 = new ASN1OutputStream.<init>(var2);

      CertificateFactory var10001;
      try {
         var10001 = CertificateFactory.getInstance("X.509", provider);
      } catch (CertificateException var7) {
         throw new OCSPException("can't get certificate factory.", var7);
      }

      CertificateFactory provider1 = var10001;
      ASN1Sequence var4;
      ByteArrayOutputStream var11;
      if ((var4 = var10000.resp.getCerts()) != null) {
         for(Enumeration var10 = var4.getObjects(); var10.hasMoreElements(); var11.reset()) {
            try {
               var11 = var2;
               var3.writeObject(var10.nextElement());
               var8.add(provider1.generateCertificate(new ByteArrayInputStream(var2.toByteArray())));
            } catch (IOException var5) {
               throw new OCSPException("can't re-encode certificate!", var5);
            } catch (CertificateException var6) {
               throw new OCSPException("can't re-encode certificate!", var6);
            }
         }
      }

      return var8;
   }

   public byte[] getTBSResponseData() {
      try {
         return this.resp.getTbsResponseData().getEncoded();
      } catch (IOException var1) {
         throw new OCSPException("problem encoding tbsResponseData", var1);
      }
   }

   public int getVersion() {
      return this.data.getVersion().getValue().intValue() + 1;
   }

   public RespID getResponderId() {
      return new RespID(this.data.getResponderID());
   }

   public Date getProducedAt() {
      try {
         return this.data.getProducedAt().getDate();
      } catch (ParseException var1) {
         throw new IllegalStateException("ParseException:" + var1.getMessage());
      }
   }

   public SingleResp[] getResponses() {
      int var1;
      ASN1Sequence var5;
      SingleResp[] var2 = new SingleResp[var1 = (var5 = this.data.getResponses()).size()];

      for(int var3 = 0; var3 != var1; ++var3) {
         SingleResp var4;
         var4 = new SingleResp.<init>(SingleResponse.getInstance(var5.getObjectAt(var3)));
         var2[var3] = var4;
      }

      return var2;
   }

   public X509Extensions getResponseExtensions() {
      return this.data.getResponseExtensions();
   }

   public boolean hasUnsupportedCriticalExtension() {
      Set var1;
      return (var1 = this.getCriticalExtensionOIDs()) != null && !var1.isEmpty();
   }

   public Set getCriticalExtensionOIDs() {
      return this.getExtensionOIDs(true);
   }

   public Set getNonCriticalExtensionOIDs() {
      return this.getExtensionOIDs(false);
   }

   public byte[] getExtensionValue(String oid) {
      X509Extensions var3;
      if ((var3 = this.getResponseExtensions()) != null) {
         X509Extensions var10000 = var3;
         DERObjectIdentifier var5;
         var5 = new DERObjectIdentifier.<init>(oid);
         cn.com.infosec.asn1.x509.X509Extension var6;
         if ((var6 = var10000.getExtension(var5)) != null) {
            ByteArrayOutputStream oid1;
            ByteArrayOutputStream var4 = oid1 = new ByteArrayOutputStream;
            var4.<init>();
            cn.com.infosec.asn1.x509.X509Extension var10002 = var6;
            DEROutputStream var10001 = new DEROutputStream(oid1);

            try {
               var10001.writeObject(var10002.getValue());
               return var4.toByteArray();
            } catch (Exception var2) {
               throw new RuntimeException("error encoding " + var2.toString());
            }
         }
      }

      return null;
   }

   public String getSignatureAlgName() {
      return OCSPUtil.getAlgorithmName(this.resp.getSignatureAlgorithm().getObjectId());
   }

   public String getSignatureAlgOID() {
      return this.resp.getSignatureAlgorithm().getObjectId().getId();
   }

   /** @deprecated */
   public RespData getResponseData() {
      return new RespData(this.resp.getTbsResponseData());
   }

   public byte[] getSignature() {
      return this.resp.getSignature().getBytes();
   }

   public X509Certificate[] getCerts(String provider) {
      List var10000 = this.getCertList(provider);
      return (X509Certificate[])var10000.toArray(new X509Certificate[var10000.size()]);
   }

   public CertStore getCertificates(String param1, String param2) {
      // $FF: Couldn't be decompiled
   }

   public boolean verify(PublicKey key, String sigProvider) {
      Exception var10000;
      label48: {
         NoSuchProviderException var13;
         Signature var14;
         boolean var10001;
         try {
            var14 = Signature.getInstance(this.getSignatureAlgName(), sigProvider);
         } catch (NoSuchProviderException var9) {
            var13 = var9;
            var10001 = false;
            throw var13;
         } catch (Exception var10) {
            var10000 = var10;
            var10001 = false;
            break label48;
         }

         Signature var15 = var14;

         BasicOCSPResp var16;
         Signature var10002;
         ByteArrayOutputStream var10003;
         try {
            var10002 = var15;
            var16 = this;
            var10002.initVerify(key);
            var10003 = new ByteArrayOutputStream;
         } catch (NoSuchProviderException var7) {
            var13 = var7;
            var10001 = false;
            throw var13;
         } catch (Exception var8) {
            var10000 = var8;
            var10001 = false;
            break label48;
         }

         ByteArrayOutputStream key1;
         ByteArrayOutputStream var10004 = key1 = var10003;

         DEROutputStream var17;
         try {
            var10004.<init>();
            var17 = new DEROutputStream;
         } catch (NoSuchProviderException var5) {
            var13 = var5;
            var10001 = false;
            throw var13;
         } catch (Exception var6) {
            var10000 = var6;
            var10001 = false;
            break label48;
         }

         DEROutputStream var10005 = var17;

         try {
            var10005.<init>(key1);
            var17.writeObject(this.resp.getTbsResponseData());
            var10002.update(var10003.toByteArray());
            return var14.verify(var16.getSignature());
         } catch (NoSuchProviderException var3) {
            var13 = var3;
            var10001 = false;
            throw var13;
         } catch (Exception var4) {
            var10000 = var4;
            var10001 = false;
         }
      }

      Exception var11 = var10000;
      throw new OCSPException("exception processing sig: " + var11, var11);
   }

   public byte[] getEncoded() {
      ByteArrayOutputStream var1;
      ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
      var10000.<init>();
      (new ASN1OutputStream(var1)).writeObject(this.resp);
      return var10000.toByteArray();
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof BasicOCSPResp)) {
         return false;
      } else {
         BasicOCSPResp var10000 = this;
         BasicOCSPResp var2 = (BasicOCSPResp)o;
         return var10000.resp.equals(var2.resp);
      }
   }

   public int hashCode() {
      return this.resp.hashCode();
   }
}
